@@ -31,7 +31,6 @@ import yaml
 
 from searchlightclient import exc
 from searchlightclient.i18n import _
-from searchlightclient.i18n import _LE
 
 
 LOG = logging.getLogger(__name__)
@@ -246,8 +245,8 @@ def format_parameter_file(param_files, template_file=None,
 
     param_file = {}
     for key, value in iter(params.items()):
-                param_file[key] = resolve_param_get_file(value,
-                                                         template_base_url)
+        param_file[key] = resolve_param_get_file(value,
+                                                 template_base_url)
     return param_file
 
 
@@ -312,7 +311,7 @@ def get_response_body(resp):
         try:
             body = resp.json()
         except ValueError:
-            LOG.error(_LE('Could not decode response body as JSON'))
+            LOG.error('Could not decode response body as JSON')
     else:
         body = None
     return body
